@@ -22,7 +22,7 @@
 #include "dstyle.h"
 
 #include <DGuiApplicationHelper>
-#include<qpa/qplatformnativeinterface.h>
+
 #ifdef Q_OS_LINUX
 #include <X11/extensions/shape.h>
 #include <QX11Info>
@@ -33,10 +33,6 @@
 
 DWIDGET_BEGIN_NAMESPACE
 
-static bool isDwayland()
-{
-    return qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
-}
 /*!
   \class Dtk::Widget::DArrowRectangle
   \inmodule dtkwidget
@@ -338,6 +334,16 @@ void DArrowRectangle::setRadiusArrowStyleEnable(bool enable)
     setArrowHeight(24);
 }
 
+/*!
+  \brief DArrowRectangle::setRadiusForceEnable 设置圆角样式.
+  \brief 默认窗管支持特效混成时有圆角，没有特效时没有圆角，如果启用一直都有圆角
+  \a enable 是否开启.
+ */
+void DArrowRectangle::setRadiusForceEnable(bool enable)
+{
+    setProperty("_d_radius_force", enable);
+}
+
 /*!
   \property DArrowRectangle::shadowXOffset
 
@@ -479,8 +485,7 @@ void DArrowRectangle::setBackgroundColor(const QColor &backgroundColor)
 
     d->m_backgroundColor = backgroundColor;
 
-    bool isFloatWindow = d->floatMode == FloatWindow;
-    if ((d->m_handle || (isFloatWindow && isDwayland())) && d->m_backgroundColor.toRgb().alpha() < 255) {
+    if (d->m_handle && d->m_backgroundColor.toRgb().alpha() < 255) {
         if (!d->m_blurBackground) {
             d->m_blurBackground = new DBlurEffectWidget(this);
             d->m_blurBackground->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
@@ -535,6 +540,18 @@ int DArrowRectangle::radius() const
     return d->m_radius;
 }
 
+/*!
+  \property DArrowRectangle::radiusForceEnabled
+
+  \brief 是否强制(忽略特效)开启圆角
+
+  Getter: DArrowRectangle::radiusForceEnabled , Setter: DArrowRectangle::setRadiusForceEnable
+ */
+bool DArrowRectangle::radiusForceEnabled() const
+{
+    return property("_d_radius_force").toBool();
+}
+
 /*!
   \property DArrowRectangle::arrowHeight
 
@@ -1117,9 +1134,6 @@ void DArrowRectanglePrivate::updateClipPath()
 {
     D_Q(DArrowRectangle);
 
-    if (!isDwayland() && !m_handle)
-        return;
-
     QPainterPath path;
 
     switch (m_arrowDirection) {
@@ -1141,7 +1155,7 @@ void DArrowRectanglePrivate::updateClipPath()
 
     if (m_handle) {
         m_handle->setClipPath(path);
-    } else if (DArrowRectangle::FloatWindow == floatMode && isDwayland()) {
+    } else {
         // clipPath without handle
         QPainterPathStroker stroker;
         stroker.setCapStyle(Qt::RoundCap);
@@ -1152,16 +1166,12 @@ void DArrowRectanglePrivate::updateClipPath()
 
         q->clearMask();
         q->setMask(polygon);
-        if (m_blurBackground)
-            m_blurBackground->setMaskPath(path);
 
         if (QWidget *widget = q->window()) {
             if (QWindow *w = widget->windowHandle()) {
                 QList<QPainterPath> painterPaths;
-                painterPaths << outPath.united(path);
-                // 背景模糊也要设置一个 path
-                qApp->platformNativeInterface()->setWindowProperty(w->handle(), "_d_windowBlurPaths",
-                                                                   QVariant::fromValue(painterPaths));
+                painterPaths << outPath;
+                w->setProperty("_d_windowBlurPaths", QVariant::fromValue(painterPaths));
             }
         }
     }
@@ -1170,7 +1180,7 @@ void DArrowRectanglePrivate::updateClipPath()
 bool DArrowRectanglePrivate::radiusEnabled()
 {
     D_Q(DArrowRectangle);
-    if (q->property("_d_radius_force").toBool())
+    if (q->radiusForceEnabled())
         return true;
 
     if (m_wmHelper && !m_wmHelper->hasComposite()) {
@@ -1228,17 +1238,8 @@ void DArrowRectanglePrivate::init(DArrowRectangle::FloatMode mode)
             q->update();
             this->updateClipPath();
         }, Qt::QueuedConnection);
-    } else if (DArrowRectangle::FloatWidget == floatMode) {
-        DGraphicsGlowEffect *glowEffect = new DGraphicsGlowEffect;
-        glowEffect->setBlurRadius(q->shadowBlurRadius());
-        glowEffect->setDistance(m_shadowDistance);
-        glowEffect->setXOffset(q->shadowXOffset());
-        glowEffect->setYOffset(q->shadowYOffset());
-        q->setGraphicsEffect(glowEffect);
     } else {
-#ifndef QT_DEBUG
-        qDebug() << "wayland:" << isDwayland() << "floatMode:" << floatMode;
-#endif
+        m_wmHelper = nullptr;
     }
 }
 
