@@ -90,35 +90,37 @@ void DFloatingMessagePrivate::init()
 }
 
 /*!
- * \~chinese \class DFloatingMessage
- * \~chinese \brief 是一个浮动消息的类, 类似于 ios 的通知栏消息, 然后有每一个新的消息对象, 就添加到一个竖直布局里面,
- * \~chinese 然后一个消息的其布局模式是: icon (图标) + Message (消息) + QWidget (存放如控件按钮,可选) + closeButton (关闭按钮,可选)
- * \~chinese 多个消息均是以竖直布局存放在一个 DMessageManager (消息管理类) 里面的
- *
- * \~chinese \htmlonly
- * <pre style="font-family: FreeMono, Consolas, Menlo, 'Noto Mono', 'Courier New', Courier, monospace;line-height: 100%;">
- * =============================================================================================
- * =                                                                                           =
- * =        ==========       =======================         =========        ==========       =
- * =        = icon   =       =        message      =         =QWidget=        =  quit  =       =
- * =        ==========       =======================         =========        ==========       =
- * =          (必选)                 (必选)                    (永驻:可选)       (永驻:可选)       =
- * =============================================================================================
- * </pre>
- * \endhtmlonly
- * \~chinese 消息通知一共有两种类型,临时停留几秒和手动清除的永驻消息
+  \class Dtk::Widget::DFloatingMessage
+  \inmodule dtkwidget
+  \brief 一个浮动消息的类.
+
+  类似于 ios 的通知栏消息, 然后有每一个新的消息对象, 就添加到一个竖直布局里面,
+  然后一个消息的其布局模式是: icon (图标) + Message (消息) + QWidget (存放如控件按钮,可选) + closeButton (关闭按钮,可选)
+  多个消息均是以竖直布局存放在一个 DMessageManager (消息管理类) 里面的
+  
+  \raw HTML
+  <pre style="font-family: FreeMono, Consolas, Menlo, 'Noto Mono', 'Courier New', Courier, monospace;line-height: 100%;">
+  =============================================================================================
+  =                                                                                           =
+  =        ==========       =======================         =========        ==========       =
+  =        = icon   =       =        message      =         =QWidget=        =  quit  =       =
+  =        ==========       =======================         =========        ==========       =
+  =          (必选)                 (必选)                    (永驻:可选)       (永驻:可选)       =
+  =============================================================================================
+  </pre>
+  \endraw
+  消息通知一共有两种类型,临时停留几秒和手动清除的永驻消息
  */
 
 /*!
- *
- * \~chinese \enum DFloatingMessage::MessageType
- * \~chinese DFloatingMessage::MessageType 定义了 DFloatingMessage 通知类型
- *
- * \~chinese \var DFloatingMessage:MessageType DFloatingMessage::TransientType
- * \~chinese 临时的消息
- *
- * \~chinese \var DDFloatingMessage:MessageType DFloatingMessage::ResidentType
- * \~chinese 常驻的消息
+  \enum Dtk::Widget::DFloatingMessage::MessageType
+  DFloatingMessage::MessageType 定义了 DFloatingMessage 通知类型
+  
+  \value TransientType
+  临时的消息
+  
+  \value ResidentType
+  常驻的消息
  */
 
 DFloatingMessage::DFloatingMessage(MessageType notifyType, QWidget *parent)
@@ -140,8 +142,8 @@ DFloatingMessage::MessageType DFloatingMessage::messageType() const
 }
 
 /*!
- * \~chinese \brief 设置控件图标 icon
- * \~chinese \param[in] ico 是最终的效果图标
+  \brief 设置控件图标 icon
+  \a ico 是最终的效果图标
  */
 void DFloatingMessage::setIcon(const QIcon &ico)
 {
@@ -150,9 +152,15 @@ void DFloatingMessage::setIcon(const QIcon &ico)
     d->iconButton->setIcon(ico);
 }
 
+void DFloatingMessage::setIcon(const DDciIcon &icon)
+{
+    D_D(DFloatingMessage);
+    d->iconButton->setIcon(icon);
+}
+
 /*!
- * \~chinese \brief 设置显示的文本消息(文字)
- * \~chinese \param[in] str 消息文本的具体文字内容
+  \brief 设置显示的文本消息(文字)
+  \a str 消息文本的具体文字内容
  */
 void DFloatingMessage::setMessage(const QString &str)
 {
@@ -162,8 +170,8 @@ void DFloatingMessage::setMessage(const QString &str)
 }
 
 /*!
- * \~chinese \brief 消息里面的,水平布局里面的第三个位置, 用来存放一些自定义控件, 比如一个确定按钮
- * \~chinese \param[in] w 插入的具体控件, 若之前此处已经有其他的控件, 先删除挪出空位子, 在将 w 控件放到这个上面
+  \brief 消息里面的,水平布局里面的第三个位置, 用来存放一些自定义控件, 比如一个确定按钮
+  \a w 插入的具体控件, 若之前此处已经有其他的控件, 先删除挪出空位子, 在将 w 控件放到这个上面
  */
 void DFloatingMessage::setWidget(QWidget *w)
 {
@@ -177,8 +185,8 @@ void DFloatingMessage::setWidget(QWidget *w)
 }
 
 /*!
- * \~chinese \brief 若是为临时消息,则设置时间(毫秒)后会自动消失
- * \~chinese \param[in] msec 消息显示的毫秒数, 默认是4000毫秒
+  \brief 若是为临时消息,则设置时间(毫秒)后会自动消失
+  \a msec 消息显示的毫秒数, 默认是4000毫秒
  */
 void DFloatingMessage::setDuration(int msec)
 {
@@ -202,8 +210,8 @@ QSize DFloatingMessage::sizeHint() const
 }
 
 /*!
- * \~chinese \brief 显示事件,里面设置计时器开始工作
- * \~chinese \param[in] event 系统传过来的显示消息事件,没有感兴趣的消息需要处理,直接所有事件继续传递给下一个对象
+  \brief 显示事件,里面设置计时器开始工作
+  \param[in] event 系统传过来的显示消息事件,没有感兴趣的消息需要处理,直接所有事件继续传递给下一个对象
  */
 void DFloatingMessage::showEvent(QShowEvent *event)
 {
