@@ -1,5 +1,8 @@
 #include "dmessagemanager.h"
+
 #include <DFloatingMessage>
+#include <DDciIcon>
+
 #include <QVBoxLayout>
 #include <QEvent>
 
@@ -57,13 +60,36 @@ bool DMessageManager::eventFilter(QObject *watched, QEvent *event)
 }
 
 DWIDGET_BEGIN_NAMESPACE
+template<typename IconType>
+static void sendMessage_helper(DMessageManager *manager, QWidget *par, IconType icon, const QString &message)
+{
+    QWidget *content = par->findChild<QWidget *>(D_MESSAGE_MANAGER_CONTENT, Qt::FindDirectChildrenOnly);
+    int text_message_count = 0;
+
+    for (DFloatingMessage *message : content->findChildren<DFloatingMessage*>(QString(), Qt::FindDirectChildrenOnly)) {
+        if (message->messageType() == DFloatingMessage::TransientType) {
+            ++text_message_count;
+        }
+    }
+
+    // TransientType 类型的通知消息，最多只允许同时显示三个
+    if (text_message_count >= 3)
+        return;
+
+    DFloatingMessage *floMsg = new DFloatingMessage(DFloatingMessage::TransientType);
+    floMsg->setAttribute(Qt::WA_DeleteOnClose);
+    floMsg->setIcon(icon);
+    floMsg->setMessage(message);
+    manager->sendMessage(par, floMsg);
+}
+
 DMessageManager::DMessageManager()               //私有静态构造函数
 {
 }
 
 /*!
- * \~chinese \brief DMessageManager::instance 构造一个单例对象
- * \~chinese \return 返回对象引用
+  \brief DMessageManager::instance 构造一个单例对象
+  \return 返回对象引用
  */
 DMessageManager *DMessageManager::instance()  //公有静态函数
 {
@@ -72,9 +98,9 @@ DMessageManager *DMessageManager::instance()  //公有静态函数
 }
 
 /*!
- * \~chinese \brief DMessageManager::sendMessage 发送弹窗消息
- * \~chinese \param par 父控件
- * \~chinese \param floMsg 弹窗浮动消息（控件）
+  \brief DMessageManager::sendMessage 发送弹窗消息
+  \a par 父控件
+  \a floMsg 弹窗浮动消息（控件）
  */
 void DMessageManager::sendMessage(QWidget *par, DFloatingMessage *floMsg)
 {
@@ -104,38 +130,26 @@ void DMessageManager::sendMessage(QWidget *par, DFloatingMessage *floMsg)
 }
 
 /*!
- * \~chinese \brief DMessageManager::sendMessage 发送弹窗消息
- * \~chinese \param par 父控件
- * \~chinese \param icon 消息图标
- * \~chinese \param message 消息文字
+  \brief DMessageManager::sendMessage 发送弹窗消息
+  \a par 父控件
+  \a icon 消息图标
+  \a message 消息文字
  */
 void DMessageManager::sendMessage(QWidget *par, const QIcon &icon, const QString &message)
 {
-    QWidget *content = par->findChild<QWidget *>(D_MESSAGE_MANAGER_CONTENT, Qt::FindDirectChildrenOnly);
-    int text_message_count = 0;
+    sendMessage_helper(instance(), par, icon, message);
+}
 
-    for (DFloatingMessage *message : content->findChildren<DFloatingMessage*>(QString(), Qt::FindDirectChildrenOnly)) {
-        if (message->messageType() == DFloatingMessage::TransientType) {
-            ++text_message_count;
-        }
-    }
-
-    // TransientType 类型的通知消息，最多只允许同时显示三个
-    if (text_message_count >= 3)
-        return;
-
-    DFloatingMessage *floMsg = new DFloatingMessage(DFloatingMessage::TransientType);
-    floMsg->setAttribute(Qt::WA_DeleteOnClose);
-    floMsg->setIcon(icon);
-    floMsg->setMessage(message);
-    sendMessage(par, floMsg);
+void DMessageManager::sendMessage(QWidget *par, const DDciIcon &icon, const QString &message)
+{
+    sendMessage_helper(instance(), par, icon, message);
 }
 
 /*!
- * \~chinese \brief DMessageManager::setContentMargens 设置中间间隔值
- * \~chinese \param par 父控件
- * \~chinese \param margins四周的间隔值
- * \~chinese \return 是否设置成功
+  \brief DMessageManager::setContentMargens 设置中间间隔值
+  \a par 父控件
+  \a margins四周的间隔值
+  \return 是否设置成功
  */
 bool DMessageManager::setContentMargens(QWidget *par, const QMargins &margins)
 {
@@ -150,10 +164,10 @@ bool DMessageManager::setContentMargens(QWidget *par, const QMargins &margins)
 }
 
 /*!
- * \~chinese \brief DMessageManager::eventFilter 消息过滤
- * \~chinese \param watched 查看对象
- * \~chinese \param event 消息事件
- * \~chinese \return 成功与否
+  \brief DMessageManager::eventFilter 消息过滤
+  \a watched 查看对象
+  \a event 消息事件
+  \return 成功与否
  */
 bool DMessageManager::eventFilter(QObject *watched, QEvent *event)
 {
