@@ -23,6 +23,7 @@
 
 #include <dtkwidget_global.h>
 #include <DPalette>
+#include <DDciIcon>
 
 #include <QCommonStyle>
 #include <QPainter>
@@ -216,6 +217,11 @@ public:
         SP_AddButton,                               //新增按钮
         SP_TitleQuitFullButton,                     //标题栏(「」)
         SP_TitleMoreButton,                         //标题栏 "更多" 按钮
+
+        SP_Title_SS_LeftButton,                     //标题栏左分屏按钮
+        SP_Title_SS_RightButton,                    //标题栏右分屏按钮
+        SP_Title_SS_ShowMaximizeButton,             //标题栏最大化分屏按钮
+        SP_Title_SS_ShowNormalButton,               //标题栏还原分屏按钮
         SP_CustomBase = QStyle::SP_CustomBase + 0xf00000
     };
 
@@ -224,12 +230,14 @@ public:
                               qint8 redFloat = 0, qint8 greenFloat = 0, qint8 blueFloat = 0, qint8 alphaFloat = 0);
     static QColor blendColor(const QColor &substrate, const QColor &superstratum);
     static QPair<QIcon::Mode, QIcon::State> toIconModeState(const QStyleOption *option);
+    static DDciIcon::Mode toDciIconMode(const QStyleOption *option);
 
     static void setTooltipTextFormat(Qt::TextFormat format);
     static Qt::TextFormat tooltipTextFormat();
     static DStyle::StyleState getState(const QStyleOption *option);
     static void setFocusRectVisible(QWidget *widget, bool visible);
     static void setFrameRadius(QWidget *widget, int radius);
+    static void setUncheckedItemIndicatorVisible(QWidget *widget, bool visible);
     DStyle();
 
     static void drawPrimitive(const QStyle *style, DStyle::PrimitiveElement pe, const QStyleOption *opt, QPainter *p, const QWidget *w = nullptr);
